@@ -1,7 +1,18 @@
+import functools
+import sys
+
+import cli_ui
+
+from gitlabform import EXIT_INVALID_INPUT
 from gitlabform.gitlab.core import GitLabCore, NotFoundException
 
 
 class GitLabGroups(GitLabCore):
+    @functools.lru_cache()
+    def get_group_id_case_insensitive(self, some_string):
+        # Cache the mapping from some_string -> id, as that won't change during our run.
+        return self.get_group_case_insensitive(some_string)["id"]
+
     def get_group_case_insensitive(self, some_string):
 
         # maybe "foo/bar" is some group's path
@@ -145,3 +156,48 @@ class GitLabGroups(GitLabCore):
             "DELETE",
             expected_codes=[200, 202, 204, 404],
         )
+
+    def get_group_shared_with(self, group):
+        group = self.get_group_case_insensitive(group)
+
+        return group["shared_with_groups"]
+
+    def add_share_to_group(
+        self, group, share_with_group_name, group_access, expires_at=None
+    ):
+        try:
+            share_with_group_id = self.get_group_id_case_insensitive(
+                share_with_group_name
+            )
+        except NotFoundException:
+            cli_ui.error(f"Group {share_with_group_name} not found.")
+            sys.exit(EXIT_INVALID_INPUT)
+
+        data = {"group_id": share_with_group_id, "expires_at": expires_at}
+        if group_access is not None:
+            data["group_access"] = group_access
+
+        return self._make_requests_to_api(
+            "groups/%s/share",
+            group,
+            method="POST",
+            data=data,
+            expected_codes=[200, 201],
+        )
+
+    def remove_share_from_group(self, group, share_with_group_name):
+        try:
+            share_with_group_id = self.get_group_id_case_insensitive(
+                share_with_group_name
+            )
+        except NotFoundException:
+            cli_ui.error(f"Group {share_with_group_name} not found.")
+            sys.exit(EXIT_INVALID_INPUT)
+
+        # 404 means that the user is already removed, so let's accept it for idempotency
+        return self._make_requests_to_api(
+            "groups/%s/share/%s",
+            (group, share_with_group_id),
+            method="DELETE",
+            expected_codes=[204, 404],
+        )
